@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0004';
+our $VERSION = '0.0005';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -66,14 +66,14 @@ has octave => (
 
 has tonic => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
+    isa     => sub { die "$_[0] is not a valid setting" unless $_[0] =~ /^-?[01]$/ },
     default => sub { 1 },
 );
 
 
 has resolve => (
     is      => 'ro',
-    isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
+    isa     => sub { die "$_[0] is not a valid setting" unless $_[0] =~ /^-?[01]$/ },
     default => sub { 1 },
 );
 
@@ -122,10 +122,29 @@ sub generate {
     my $v;
     for my $n (1 .. $self->max) {
         if ($n == 1) {
-            $v = $self->tonic ? 1 : (keys %{ $self->net })[int rand keys %{ $self->net }];
+            if ($self->tonic == 0) {
+                $v = (@{ $self->net->{1} })[int rand @{ $self->net->{1} }];
+            }
+            elsif ($self->tonic == 1) {
+                $v = 1;
+            }
+            else {
+                my @keys = grep { keys @{ $self->net->{$_} } > 0 } keys %{ $self->net };
+                $v = $keys[int rand @keys];
+            }
         }
         elsif ($n == $self->max) {
-            $v = $self->resolve ? 1 : (keys %{ $self->net })[int rand keys %{ $self->net }];
+            if ($self->resolve == 0) {
+                my @keys = keys %{ $self->net };
+                $v = (@{ $self->net->{ scalar @keys } })[int rand @{ $self->net->{ scalar @keys } }];
+            }
+            elsif ($self->resolve == 1) {
+                $v = 1;
+            }
+            else {
+                my @keys = grep { keys @{ $self->net->{$_} } > 0 } keys %{ $self->net };
+                $v = $keys[int rand @keys];
+            }
         }
         else {
             $v = $self->graph->random_successor($v);
@@ -223,7 +242,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0004
+version 0.0005
 
 =head1 SYNOPSIS
 
@@ -270,6 +289,21 @@ Alternative example:
     5 => [qw( 1 )],
     6 => [qw( 2 4 )] }
 
+The keys must start with C<1> and end on a number less than or equal
+to C<7>.  If you do not wish a scale note, that is located in the
+middle of the range, to be chosen, include it among the keys, but do
+not refer to it and do not give it any neighbors.
+
+For example, the chord for the 5th degree of the scale will not be
+chosen here, because no key refers to it and it has no neighbors:
+
+  { 1 => [qw( 1 2 3 4 6 7)],
+    2 => [qw( 3 )],
+    3 => [qw( 2 4 6 )],
+    4 => [qw( 1 2 3 )],
+    5 => [],
+    6 => [qw( 2 4 )] }
+
 =head2 chords
 
 The chord name parts of each scale position.
@@ -305,12 +339,20 @@ Default: C<4>
 
 Whether to start the progression with the tonic chord or not.
 
+If this is given as C<1> the tonic chord starts the progression.  If
+given as C<0> a neighbor of the tonic is chosen.  If given as C<-1> a
+random vertex is chosen.
+
 Default: C<1>
 
 =head2 resolve
 
 Whether to end the progression with the tonic chord or not.
 
+If this is given as C<1> the tonic chord ends the progression.  If
+given as C<0> a neighbor of the tonic is chosen.  If given as C<-1> a
+random vertex is chosen.
+
 Default: C<1>
 
 =head2 substitute
@@ -339,24 +381,34 @@ Show the progress of the B<generate> method.
 
 =head2 new
 
-  $prog = Music::Chord::Progression->new;
-  $prog = Music::Chord::Progression->new(
+  $prog = Music::Chord::Progression->new; # Use the defaults
+
+  $prog = Music::Chord::Progression->new( # Override the defaults
+    max        => 4,
     net        => { 1 => [...], ... },
     chords     => ['m','','m','m','',''],
     scale_name => 'minor',
     scale_note => 'A',
     octave     => 5,
+    tonic      => 0,
+    resolve    => 0,
+    substitute => 1,
+    verbose    => 1,
   );
 
 Create a new C<Music::Chord::Progression> object.
 
 =head2 generate
 
+  $notes = $prog->generate;
+
 Generate a new chord progression.
 
 =head2 substitution
 
-Perform a jazz substitution on the given B<chord>.
+  $substitute = $prog->substitution($chord_name);
+
+Perform a jazz substitution on the given the B<chord_name>.
 
 Rules:
 
